BioPortalClient
===============

.. currentmodule:: ontoportal_client.api

.. autoclass:: BioPortalClient
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~BioPortalClient.name

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
